==> planeshift-0.3.016.tar.bz2: planeshift-0.3.016/src/server/database/mysql/progress_events.sql <==
# MySQL-Front Dump 1.16 beta
#
# Host: localhost Database: planeshift
#--------------------------------------------------------
# Server version 4.0.18-max-nt
#
# Table structure for table 'progression_events'
#

CREATE TABLE progression_events (
  name varchar(40) NOT NULL DEFAULT '' ,
  event_script text NOT NULL DEFAULT '' ,
  PRIMARY KEY (name)
);


#
# Dumping data for table 'progression_events'
#

INSERT INTO progression_events VALUES("DamageHP","<evt><hp aim=\"target\" value=\"-Param0\" save=\"Result\" /><msg aim=\"target\" text=\"You lost $Param0 hitpoints\"/><msg aim=\"actor\" text=\"Target hit for $Param0 hitpoints\"/></evt>");
INSERT INTO progression_events VALUES("GainHP","<evt><hp aim=\"target\" value=\"Param0\" /><msg aim=\"actor\" text=\"You gained $Param0 hitpoints\"/><msg text=\"Gained $Param0 hitpoints\"/></evt>");
INSERT INTO progression_events VALUES("give_exp","<evt><exp value=\"Param0\" /></evt>");
INSERT INTO progression_events VALUES("kill","<evt><exp value=\"Target:KillExp\" /></evt>");
INSERT INTO progression_events VALUES("killed orc","<evt><faction name=\"orcs\" value=\"1\" /></evt>");
INSERT INTO progression_events VALUES("killed conservative","<evt><faction name=\"liberals\" value=\"2\" /></evt>");
INSERT INTO progression_events VALUES("cast_life_infusion","<evt><hp aim=\"target\" value=\"2*Actor:PowerLevel+3\" /><msg text=\"You feel fresh\"/></evt>");
INSERT INTO progression_events VALUES("cast_energy_arrow","<evt><msg text=\"You attempt to cast Energy Arrow\" /></evt>");
INSERT INTO progression_events VALUES("cast_energy_arrow_save","<evt><msg text=\"Saved against Energy Arrow\" /></evt>");
INSERT INTO progression_events VALUES("effect_energy_arrow","<evt><hp aim=\"target\" value=\"-5\" save=\"spelldamage\"/><msg text=\"You deal $spelldamage damage.\"/></evt>");
INSERT INTO progression_events VALUES("caster_flame_shot","<evt><msg text=\"You attempt to cast Flame Shot.\" /></evt>");
INSERT INTO progression_events VALUES("effect_flame_shot","<evt><hp aim=\"target\" value=\"-15+rnd(5)\"  save=\"spelldamage\"/><msg text=\"Your spell did $spelldamage damage.\"/></evt>");
INSERT INTO progression_events VALUES("caster_flame_spiral","<evt><msg text=\"You attempt to cast Flame Spiral.\" /></evt>");
INSERT INTO progression_events VALUES("effect_flame_spiral","<evt><hp aim=\"target\" value=\"rnd(25)\" /><msg text=\"You do a random amount of damage.\"/></evt>");
INSERT INTO progression_events VALUES("caster_flame_fountain","<evt><msg text=\"You deal 25-35 HP damage\" /><script delay=\"3000\"><hp value=\"5\"/><msg text=\"You feel fresh\"/></script></evt>");
INSERT INTO progression_events VALUES("effect_flame_fountain","<evt><hp aim=\"target\" value=\"-25-rnd(10)\" /><script delay=\"3000\"><hp value=\"-5\"/></script></evt>");
INSERT INTO progression_events VALUES("char_test","<evt><faction name=\"orcs\" value=\"-1\"/></evt>");
INSERT INTO progression_events VALUES("mageFather","<evt><int attribute=\"adjust\" base=\"yes\" value=\"5*Parm0\" /></evt>");
INSERT INTO progression_events VALUES("drink_potion","<evt><hp attribute=\"adjust\" base=\"no\" value=\"10\" /><msg text=\"You drink an healing potion and feel better.\"/></evt>");
INSERT INTO progression_events VALUES("drink_poison","<evt><hp attribute=\"adjust\" base=\"no\" value=\"-20\" /><msg text=\"You drink some poison and feel bad.\"/></evt>");
INSERT INTO progression_events VALUES("equip_mind","<evt><msg text=\"You now have something in mind.\"/></evt>");
INSERT INTO progression_events VALUES("de_equip_mind","<evt><msg text=\"Your mind is now clear.\"/></evt>");
INSERT INTO progression_events VALUES("equip_ring_hp","<evt><hp attribute=\"adjust\" base=\"yes\" value=\"10\" /><msg text=\"You hear the dark lord calling for you.\"/></evt>");
INSERT INTO progression_events VALUES("de_equip_ring_hp","<evt><hp attribute=\"adjust\" base=\"yes\" value=\"-10\" /><msg text=\"You feel you've lost an old friend.\"/></evt>");
INSERT INTO progression_events VALUES("equip_ring_mana","<evt><str attribute=\"adjust\" base=\"yes\" value=\"10\" /><msg text=\"You feel stronger.\"/></evt>");
INSERT INTO progression_events VALUES("equip_ring_strength","<evt><str attribute=\"adjust\" base=\"no\" value=\"10\" /><msg text=\"You feel stronger.\"/></evt>");
INSERT INTO progression_events VALUES("drink_speed_potion","<evt><move duration=\"10\" type=\"mod\" x=\"2.0\" y=\"2.0\" z=\"2.0\" /><msg text=\"You drink an speed potion and feel very fast.\"/></evt>");
INSERT INTO progression_events VALUES("drink_strange_potion","<evt><move duration=\"10\" type=\"mod\" x=\"-0.8\" z=\"-1.1\" yrot=\"5.0\" /><move type=\"push\" y=\"6.0\" yrot=\"10.0\" /><msg text=\"You feel very dizzy\"/></evt>");
INSERT INTO progression_events VALUES('failed_fly', '<evt><hp attribute="adjust" base="no" value="-45" /><msg text="You failed horribly to fly and injured yourself badly"/></evt>');
INSERT INTO progression_events VALUES('create_familiar','<evt><createfamiliar /><msg text="Your new familiar appears nearby."/></evt>');
INSERT INTO progression_events VALUES('kick_you','<evt><hp aim=\"actor\" value=\"20\" save=\"Result\" /><msg aim=\"target\" text=\"You lost $Param0 hitpoints\"/><msg aim=\"actor\" text=\"Target kicked for $Param0 hitpoints\"/></evt>');
INSERT INTO progression_events VALUES('fire_damage','<evt><hp aim=\"actor\" value=\"-6\" /><msg text=\"You touch the ingots and your hand is burned!\"/></evt>');
INSERT INTO progression_events VALUES('healing_tree','<evt><hp aim=\"actor\" value=\"6\" /><msg text=\"Walking near the tree you feel refreshed!\"/></evt>');
INSERT INTO progression_events VALUES('morph_ulbernaut','<evt><morph mesh=\"ulbernaut\" duration=\"60\" /><msg text=\"You turn into a lumbering giant!\"/></evt>');
INSERT INTO progression_events VALUES('stronglegs','<evt><set attrib=\"nofalldamage\" duration=\"120\" /><set attrib=\"nevertired\" duration=\"120\" /><msg text=\"Your legs feel more powerful!\"/></evt>');
INSERT INTO progression_events VALUES('rain','<evt><weather type=\"rain\" sector=\"this\" duration=\"60\" fade=\"10\" density=\"8000\" /></evt>');
INSERT INTO progression_events VALUES("explosion","<evt><msg aim=\"actor\" text=\"The bottle explodes and the blast hits everyone in within 10m for 1000HP damage each.\"/><area type=\"actor\" range=\"10\"><hp aim=\"target\" value=\"-1000\" /><msg aim=\"target\" text=\"You lost 1000 hitpoints!\"/></area></evt>");

==> planeshift-0.3.017.tar.bz2: planeshift-0.3.017/src/server/database/mysql/progress_events.sql <==
# MySQL-Front Dump 1.16 beta
#
# Host: localhost Database: planeshift
#--------------------------------------------------------
# Server version 4.0.18-max-nt
#
# Table structure for table 'progression_events'
#

CREATE TABLE progression_events (
  name varchar(40) NOT NULL DEFAULT '' ,
  event_script text NOT NULL DEFAULT '' ,
  PRIMARY KEY (name)
);


#
# Dumping data for table 'progression_events'
#

INSERT INTO progression_events VALUES("DamageHP","<evt><hp aim=\"target\" value=\"-Param0\" save=\"Result\" /><msg aim=\"target\" text=\"You lost $Param0 hitpoints\"/><msg aim=\"actor\" text=\"You hit $Target for $Param0 hitpoints.\"/></evt>");
INSERT INTO progression_events VALUES("GainHP","<evt><hp aim=\"target\" value=\"Param0\" /><msg aim=\"actor\" text=\"You gained $Param0 hitpoints\"/><msg text=\"Gained $Param0 hitpoints\"/></evt>");
INSERT INTO progression_events VALUES("give_exp","<evt><exp value=\"Param0\" /></evt>");
INSERT INTO progression_events VALUES("kill","<evt><exp value=\"Target:KillExp\" /></evt>");
INSERT INTO progression_events VALUES("killed orc","<evt><faction name=\"orcs\" value=\"1\" /></evt>");
INSERT INTO progression_events VALUES("killed conservative","<evt><faction name=\"liberals\" value=\"2\" /></evt>");
INSERT INTO progression_events VALUES("cast_life_infusion","<evt><hp aim=\"target\" value=\"2*Actor:PowerLevel+3\" /><msg text=\"You feel fresh\"/></evt>");
INSERT INTO progression_events VALUES("cast_energy_arrow","<evt><msg text=\"You attempt to cast Energy Arrow\" /></evt>");
INSERT INTO progression_events VALUES("cast_energy_arrow_save","<evt><msg text=\"Saved against Energy Arrow\" /></evt>");
INSERT INTO progression_events VALUES("effect_energy_arrow","<evt><hp aim=\"target\" value=\"-5\" save=\"spelldamage\"/><msg text=\"You deal $spelldamage damage.\"/></evt>");
INSERT INTO progression_events VALUES("caster_flame_shot","<evt><msg text=\"You attempt to cast Flame Shot.\" /></evt>");
INSERT INTO progression_events VALUES("effect_flame_shot","<evt><hp aim=\"target\" value=\"-15+rnd(5)\"  save=\"spelldamage\"/><msg text=\"Your spell did $spelldamage damage.\"/></evt>");
INSERT INTO progression_events VALUES("caster_flame_spiral","<evt><msg text=\"You attempt to cast Flame Spiral.\" /></evt>");
INSERT INTO progression_events VALUES("effect_flame_spiral","<evt><hp aim=\"target\" value=\"rnd(25)\" /><msg text=\"You do a random amount of damage.\"/></evt>");
INSERT INTO progression_events VALUES("caster_flame_fountain","<evt><msg text=\"You deal 25-35 HP damage\" /><script delay=\"3000\"><hp value=\"5\"/><msg text=\"You feel fresh\"/></script></evt>");
INSERT INTO progression_events VALUES("effect_flame_fountain","<evt><hp aim=\"target\" value=\"-25-rnd(10)\" /><script delay=\"3000\"><hp value=\"-5\"/></script></evt>");
INSERT INTO progression_events VALUES("char_test","<evt><faction name=\"orcs\" value=\"-1\"/></evt>");
INSERT INTO progression_events VALUES("mageFather","<evt><int attribute=\"adjust\" base=\"yes\" value=\"5*Parm0\" /></evt>");
INSERT INTO progression_events VALUES("drink_potion","<evt><hp attribute=\"adjust\" base=\"no\" value=\"10\" /><msg text=\"You drink an healing potion and feel better.\"/></evt>");
INSERT INTO progression_events VALUES("drink_poison","<evt><hp attribute=\"adjust\" base=\"no\" value=\"-20\" /><msg text=\"You drink some poison and feel bad.\"/></evt>");
INSERT INTO progression_events VALUES("equip_mind","<evt><msg text=\"You now have something in mind.\"/></evt>");
INSERT INTO progression_events VALUES("de_equip_mind","<evt><msg text=\"Your mind is now clear.\"/></evt>");
INSERT INTO progression_events VALUES("equip_ring_hp","<evt><hp attribute=\"adjust\" base=\"yes\" value=\"10\" /><msg text=\"You hear the dark lord calling for you.\"/></evt>");
INSERT INTO progression_events VALUES("de_equip_ring_hp","<evt><hp attribute=\"adjust\" base=\"yes\" value=\"-10\" /><msg text=\"You feel you've lost an old friend.\"/></evt>");
INSERT INTO progression_events VALUES("equip_ring_mana","<evt><str attribute=\"adjust\" base=\"yes\" value=\"10\" /><msg text=\"You feel stronger.\"/></evt>");
INSERT INTO progression_events VALUES("equip_ring_strength","<evt><str attribute=\"adjust\" base=\"no\" value=\"10\" /><msg text=\"You feel stronger.\"/></evt>");
INSERT INTO progression_events VALUES("drink_speed_potion","<evt><move duration=\"10\" type=\"mod\" x=\"2.0\" y=\"2.0\" z=\"2.0\" /><msg text=\"You drink an speed potion and feel very fast.\"/></evt>");
INSERT INTO progression_events VALUES("drink_strange_potion","<evt><move duration=\"10\" type=\"mod\" x=\"-0.8\" z=\"-1.1\" yrot=\"5.0\" /><move type=\"push\" y=\"6.0\" yrot=\"10.0\" /><msg text=\"You feel very dizzy\"/></evt>");
INSERT INTO progression_events VALUES('failed_fly', '<evt><hp attribute="adjust" base="no" value="-45" /><msg text="You failed horribly to fly and injured yourself badly"/></evt>');
INSERT INTO progression_events VALUES('create_familiar','<evt><createfamiliar /><msg text="Your new familiar appears nearby."/></evt>');
INSERT INTO progression_events VALUES('kick_you','<evt><hp aim=\"actor\" value=\"20\" save=\"Result\" /><msg aim=\"target\" text=\"You lost $Param0 hitpoints\"/><msg aim=\"actor\" text=\"Target kicked for $Param0 hitpoints\"/></evt>');
INSERT INTO progression_events VALUES('fire_damage','<evt><hp aim=\"actor\" value=\"-6\" /><msg text=\"You touch the ingots and your hand is burned!\"/></evt>');
INSERT INTO progression_events VALUES('healing_tree','<evt><hp aim=\"actor\" value=\"6\" /><msg text=\"Walking near the tree you feel refreshed!\"/></evt>');
INSERT INTO progression_events VALUES('morph_ulbernaut','<evt><morph mesh=\"ulbernaut\" duration=\"60\" /><msg text=\"You turn into a lumbering giant!\"/></evt>');
INSERT INTO progression_events VALUES('stronglegs','<evt><set attrib=\"nofalldamage\" duration=\"120\" /><set attrib=\"nevertired\" duration=\"120\" /><msg text=\"Your legs feel more powerful!\"/></evt>');
INSERT INTO progression_events VALUES('rain','<evt><weather type=\"rain\" sector=\"this\" duration=\"60\" fade=\"10\" density=\"8000\" /></evt>');
INSERT INTO progression_events VALUES("explosion","<evt><msg aim=\"actor\" text=\"The bottle explodes and the blast hits everyone in within 10m for 1000HP damage each.\"/><area type=\"actor\" range=\"10\"><hp aim=\"target\" value=\"-1000\" /><msg aim=\"target\" text=\"You lost 1000 hitpoints!\"/></area></evt>");
